@@ -10,14 +10,16 @@ import re
 from lib.core.enums import HTTP_HEADER
 from lib.core.settings import WAF_ATTACK_VECTORS
 
-__product__ = "Sucuri WebSite Firewall"
+__product__ = "CloudProxy WebSite Firewall (Sucuri)"
 
 def detect(get_page):
     retval = False
 
     for vector in WAF_ATTACK_VECTORS:
-        _, headers, code = get_page(get=vector)
+        page, headers, code = get_page(get=vector)
         retval = code == 403 and re.search(r"Sucuri/Cloudproxy", headers.get(HTTP_HEADER.SERVER, ""), re.I) is not None
+        retval |= "Sucuri WebSite Firewall - CloudProxy - Access Denied" in (page or "")
+        retval |= re.search(r"Questions\?.+cloudproxy@sucuri\.net", (page or "")) is not None
         if retval:
             break
 
